/* mod_rivet_generator.h -- Content generation functions */

/*
    Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.
*/

#ifndef __mod_rivet_generator_h__
#define __mod_rivet_generator_h__

#include "mod_rivet.h"

extern int Rivet_CheckType (request_rec* r);
extern int Rivet_ParseExecFile (rivet_thread_private* req, char* filename, int toplevel);
extern int Rivet_ParseExecString (rivet_thread_private* req, Tcl_Obj* inbuf);
extern int Rivet_SendContent (rivet_thread_private* private);

#endif
